<?php

namespace BookneticAddon\AqayepardakhtPaymentGateway;

use BookneticApp\Backend\Appointments\Helpers\AppointmentRequestData;
use BookneticApp\Backend\Appointments\Helpers\AppointmentRequests;
use BookneticApp\Providers\Helpers\Helper;
use BookneticApp\Providers\Common\PaymentGatewayService;
use BookneticApp\Providers\Core\Permission;
// use Aqayepardakht\Exception\ApiErrorException;
use function BookneticAddon\AqayepardakhtPaymentGateway\bkntc__;


class Aqayepardakht extends PaymentGatewayService
{

	protected $slug = 'aqayepardakht';

	private $_paymentId;
	private $_successURL;
	private $_cancelURL;
    private $_itemList = [];


	public function __construct()
	{
		$this->setTitle( bkntc__( 'Credit card' ) );
		$this->setIcon( AqayepardakhtAddon::loadAsset( 'assets/frontend/icons/aqayepardakht.png' ) );

		//\Idpay\Idpay::setApiKey( Helper::getOption('idpay_client_secret') );
	}

	public function when( $status, $appointmentRequests = null )
	{
		if( $status && Helper::getOption('hide_confirm_details_step', 'off') == 'on' )
		{
			return false;
		}

		return $status;
	}

	public function setId( $paymentId )
	{
		$this->_paymentId = $paymentId;

		return $this;
	}

    public function setAmount( $price , $currency = 'IRT' )
    {
        if($currency == 'IRR')
        {
            return $price/10;
        }
        return $price;
    }
 
    public function addItem( $price , $currency , $itemName , $customerData )
    {
        $this->_itemList[] = [
            'price' => $this->setAmount($price, $currency),
            'quantity' => 1,
            'itemname' => $itemName,
            'customerdata' => $customerData
        ];
        return $this;
    }
	public function setSuccessURL( $url )
	{
		$this->_successURL = $url;

		return $this;
	}

	public function setCancelURL( $url )
	{
		$this->_cancelURL = $url;

		return $this;
	}

	private function createPaymentRequest()
    {
        
        $amount = array_sum(array_map( function ($item){
            return $item['price'] * $item['quantity'];
        },$this->_itemList));
        
        $mobile = null;
        $desc = null;
        foreach($this->_itemList as $item)
        {
            if(array_key_exists('customerdata',$item))
            {
                $desc .= ' رزرو : '.$item['itemname'].' | ';
                if(array_key_exists('first_name',$item['customerdata']) && array_key_exists('last_name',$item['customerdata']))
                {
                    $desc .=" پرداخت کننده : ".$item['customerdata']['first_name'].' '.$item['customerdata']['last_name'];
                }
                $mobile = array_key_exists('phone',$item['customerdata'])? $item['customerdata']['phone']:null;
            }
        }
        $aqayepardakht = new AqayepardakhtApi(Helper::getOption('aqayepardakht_pin'));
		
		$callback = $this->_successURL;
		$mobile = str_replace("+98","0",$mobile);

		$mres = $aqayepardakht->payment($amount,$callback, $this->_paymentId,$mobile, $desc);
        if ($mres) {
            // $payinfs = json_encode(['type'=>'Idpay','amount'=>$amount]);
            // $insertData = ['appointment_id'=> $id, 'description' => $payinfs];
            // Paymentinfs::insert($insertData);
            Helper::setoption('aqayepardakht_'.$this->_paymentId,$amount);
            return [
                'status'	=> true,
                'url'		=>  'https://panel.aqayepardakht.ir/startpay/'.$mres
            ];
        }else{
            $msg = 'متاسفانه با اشکال مواجه شده است';
            return [
                'status'	=> false,
                'url'		=> $msg
            ];
        }
	}

   
    /**
     * @param AppointmentRequests $appointmentRequests
     * @return object
     */
    public function doPayment( $appointmentRequests )
    {
	    $tenant_id_param = ( Helper::isSaaSVersion() ? '&tenant_id=' . Permission::tenantId() : '' );

		$this->setId( $appointmentRequests->paymentId  );
        foreach ( $appointmentRequests->appointments as $appointmentObj)
        {
            $this->addItem(
                $appointmentObj->getPayableToday( true ),
                Helper::getOption('currency', 'IRR') ,
                $appointmentObj->serviceInf->name,
                $appointmentObj->customerData
            );

        }      
		$this->setSuccessURL(site_url() . '/?bkntc_aqayepardakht_status=success&booknetic_payment_id='.$appointmentRequests->paymentId . $tenant_id_param . $tenant_id_param);
		$this->setCancelURL(site_url() . '/?bkntc_aqayepardakht_status=cancel&booknetic_payment_id='.$appointmentRequests->paymentId . $tenant_id_param);

		$aqayepardakht = $this->createPaymentRequest();
		if($aqayepardakht['status'])
        {
            $data = [ 'url' => $aqayepardakht['url'] ];

        }else{
            $data = [ 'error_msg' =>  $aqayepardakht['url']];
        }
         

		return (object) [
			'status'    => $aqayepardakht['status'],
			'data'      => $data
		];
    }

}